==> Decorative%20Food-1.20.1-1.0.8-sources.jar: org/dfood/item/ModMilkBucketItem.java <==
package org.dfood.item;

import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_3222;
import net.minecraft.class_3468;
import net.minecraft.class_5328;
import net.minecraft.item.*;

public class ModMilkBucketItem extends class_1747 {

    public ModMilkBucketItem(class_2248 block, class_1793 settings) {
        super(block, settings);
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        if (user instanceof class_3222 serverPlayerEntity) {
            class_174.field_1198.method_8821(serverPlayerEntity, stack);
            serverPlayerEntity.method_7259(class_3468.field_15372.method_14956(this));
        }

        if (user instanceof class_1657 && !((class_1657)user).method_31549().field_7477) {
            stack.method_7934(1);
        }

        if (!world.field_9236) {
            user.method_6012();
        }

        return stack.method_7960() ? new class_1799(class_1802.field_8550) : stack;
    }

    @Override
    public int method_7881(class_1799 stack) {
        return 32;
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8946;
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        return class_5328.method_29282(world, user, hand);
    }
}

==> Decorative%20Food-1.21.1-1.0.6-sources.jar: org/dfood/item/ModMilkBucketItem.java <==
package org.dfood.item;

import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1747;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1839;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_3222;
import net.minecraft.class_3468;
import net.minecraft.class_5328;

public class ModMilkBucketItem extends class_1747 {
    public ModMilkBucketItem(class_2248 block, class_1793 settings) {
        super(block, settings);
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        if (user instanceof class_3222 serverPlayerEntity) {
            class_174.field_1198.method_8821(serverPlayerEntity, stack);
            serverPlayerEntity.method_7259(class_3468.field_15372.method_14956(this));
        }

        if (!world.field_9236) {
            user.method_6012();
        }

        if (user instanceof class_1657 playerEntity) {
            return class_5328.method_30270(stack, playerEntity, new class_1799(class_1802.field_8550), false);
        } else {
            stack.method_57008(1, user);
            return stack;
        }
    }

    @Override
    public int method_7881(class_1799 stack, class_1309 user) {
        return 32;
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8946;
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        return class_5328.method_29282(world, user, hand);
    }
}
